@@ -351,9 +351,9 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
                     weight_actual_predictions = actual_predictions.numpy()[:,weight_index]
                     weight_feature_effect = weight_shap_values.sum(axis=1)
                     weight_actual_predictions_from_shapley_values = weight_expected_values + weight_feature_effect
-                    if np.sum(np.abs(weight_actual_predictions - weight_actual_predictions_from_shapley_values)) > 1e-6:
+                   # if np.sum(np.abs(weight_actual_predictions - weight_actual_predictions_from_shapley_values)) > 1e-6:
                         #raise Exception('Mismatch between shapley values and actual predictions')
-                        print('Mismatch between shapley values and actual predictions')
+                        #print('Mismatch between shapley values and actual predictions')
 
         predictors_shap_values = [list_average(shap_values)]
         predictors_feature_order = np.argsort(np.sum(np.mean(np.abs(predictors_shap_values), axis=0), axis=0))
